@@ -4,7 +4,6 @@ from aiopath import AsyncPath
 from rich.console import Console
 
 from localhttps.app import App
-from localhttps.cert.ca import CertificationAuthority
 from localhttps.cmd import Cmd
 from localhttps.keychain.abc import AbstractKeychain
 
@@ -16,7 +15,6 @@ class Context:
     data_path: AsyncPath
     app: App
     keychain: AbstractKeychain
-    ca: CertificationAuthority
 
     def exit(self, code: int = 0) -> NoReturn:
         self.click.exit(code)
